@@ -69,8 +69,8 @@ def read_csv(fname):
             for line in f.readlines():
                 data = line[:-1].split(",")
                 x.append(data)
-    except FileNotFoundError as err:
-        print(err)
+    except FileNotFoundError:
+        pass
 
     x = np.array(x)
     return x
@@ -156,7 +156,7 @@ class Detector:
 
     def __init__(self, model_file=join(SAVEDIR, "mlads_model.sav"),
                  label_encoder_file=join(SAVEDIR, "mlads_label_encoder.sav"),
-                 train_data_file=join(CSVDIR, "Xample_Training_Data.csv")):
+                 train_data_file=None):
         """Define initial values for various class attributes.
 
         Define the database object, attempt to load an existing trained algorithm, otherwise create and train a new one.
@@ -251,6 +251,8 @@ class Detector:
         x : numpy.array
             The dataset on which predictions are to be made
         """
+        if len(x) == 0:
+            return
         x_enc = self.encode_data(x)
         y_pred = self.classifier.predict(x_enc)
         x_dec = self.decode_data(x_enc, y_pred)
