@@ -184,43 +184,50 @@ class GUI:
         # Define initial values needed through the method, and get data from the database
         values = table.item(focus)['values']
         details_window = tk.Toplevel(self.window)
-        colnames, data = self.db.select_all_alerts(values[0])
-        boxes = []
-        labels = []
-        newrow = 1
-        newcol = 0
+        if len(values) == 0:
+            details_window.wm_title("Error")
+            label = ttk.Label(details_window, text='Please select a line to see more details...')
+            label.pack()
+            button = ttk.Button(details_window, text="Okay", command=details_window.destroy)
+            button.pack()
+        else:
+            colnames, data = self.db.select_all_alerts(values[0])
+            boxes = []
+            labels = []
+            newrow = 1
+            newcol = 0
 
-        if data is not None:
-            # For each column in the data, create a label and a textbox to put the values into
-            for i in range(0, len(data)):
-                # To place each item correctly in the window, i.e. 3 columns and x many rows
-                if newcol >= 6:
-                    newrow += 1
-                    newcol = 0
+            if data is not None:
+                # For each column in the data, create a label and a textbox to put the values into
+                for i in range(0, len(data)):
+                    # To place each item correctly in the window, i.e. 3 columns and x many rows
+                    if newcol >= 6:
+                        newrow += 1
+                        newcol = 0
 
-                if colnames[i] == "id" and i > 1:
-                    continue
+                    if colnames[i] == "id" and i > 1:
+                        continue
 
-                new_label = tk.Label(details_window, text=colnames[i])
-                if colnames[i] == "summary":
-                    new_label.grid(row=0, column=0, sticky=tk.W)
-                else:
-                    new_label.grid(row=newrow, column=newcol, sticky=tk.E)
-                    newcol += 1
+                    new_label = tk.Label(details_window, text=colnames[i])
+                    if colnames[i] == "summary":
+                        new_label.grid(row=0, column=0, sticky=tk.W)
+                    else:
+                        new_label.grid(row=newrow, column=newcol, sticky=tk.E)
+                        newcol += 1
 
-                new_entry = tk.Entry(details_window, width=30)
-                # We want the summary of the alert to be on its own row
-                if colnames[i] == "summary":
-                    new_entry.grid(row=0, column=1, sticky=tk.W, columnspan=5)
-                    new_entry.config(width=116)
-                else:
-                    new_entry.grid(row=newrow, column=newcol, sticky=tk.W)
-                    newcol += 1
-                new_entry.insert(tk.END, data[i])
-                new_entry.config(state='disabled')
+                    new_entry = tk.Entry(details_window, width=30)
+                    # We want the summary of the alert to be on its own row
+                    if colnames[i] == "summary":
+                        new_entry.grid(row=0, column=1, sticky=tk.W, columnspan=5)
+                        new_entry.config(width=116)
+                    else:
+                        new_entry.grid(row=newrow, column=newcol, sticky=tk.W)
+                        newcol += 1
+                    new_entry.insert(tk.END, data[i])
+                    new_entry.config(state='disabled')
 
-                boxes.append(new_entry)
-                labels.append(new_label)
+                    boxes.append(new_entry)
+                    labels.append(new_label)
 
     def analyse_window(self):
         """Allows the user to upload new PCAPs or use existing files to access the machine learning detector.
@@ -243,7 +250,11 @@ class GUI:
         # Create the variables needed for the optionbox
         existing_files = os.listdir(CSVDIR)
         file_var = tk.StringVar(self.window)
-        file_var.set(existing_files[0])
+        if len(existing_files) == 0:
+            file_var.set("No CSVs yet...")
+            existing_files.append('No CSVs yet...')
+        else:
+            file_var.set(existing_files[0])
 
         load_existing_opbox = tk.OptionMenu(self.window, file_var, *existing_files)
         load_existing_opbox.grid(row=0, column=1)
@@ -309,6 +320,9 @@ class GUI:
         filename : str
             The filename of the file to be read from
         """
+        if filename == 'No CSVs yet...':
+            return
+
         # Make sure we are reading the csv file
         csv_filename = abspath(join(CSVDIR, filename))
         try:
@@ -320,9 +334,8 @@ class GUI:
             # Predict which streams are malicious
             self.det.predict(x)
         except IOError as e:
-            # If we can't read the file, tell us and exit the program
+            # If we can't read the file, tell us
             print(e)
-            self.quit()
 
     def upload_file_window(self):
         """A window to select a file to upload to the MLADS project.
@@ -348,7 +361,8 @@ class GUI:
                                                                                                           "*.*"))))])
         browse_btn.grid(row=0, column=2, sticky=tk.W)
         upload_btn = tk.Button(upload_window, text='Upload',
-                               command=lambda: self.upload_file(browse_entry.get(), upload_window))
+                               command=lambda: [self.upload_file(browse_entry.get(), upload_window),
+                                                self.analyse_window])
         upload_btn.grid(row=0, column=3, sticky=tk.W)
 
     @staticmethod
